@@ -28,4 +28,4 @@ for file in $CONFIG_AUX_FILES; do
     esac
 done
 
-autoconf
+autoconf2.50
